@@ -28,5 +28,5 @@ class Client:
         return self._android(device_id)
 
     def get_pos(self, device_client):
-        device_client.take_screenshot()
+        return device_client.take_screenshot()
 
